<?php
require 'vendor/autoload.php';
$ini = parse_ini_file('./config.ini.php', true);

$time_format = $ini['time_format'];
$time_seperator = $ini['time_seperator'];
$weekday = $ini['weekdays'];
$month = $ini['months'];
$time_of_day = $ini['locale']['time_of_day'];
$description = $ini['locale']['description'];
$location = $ini['locale']['location'];

$client = new Google_Client();
$client -> setApplicationName("Google Calendar plugin for Xibo");
$client -> setDeveloperKey($ini['api']['api_key']);

//Set up proxy settings:
if ( isset($ini['proxy']['host']) &&
	 !empty($ini['proxy']['host']) ) {
	$client->getIo()->setOptions(array(
		CURLOPT_HTTPPROXYTUNNEL => true,
		CURLOPT_PROXY => $ini['proxy']['host']
		));
	
	// If there is a port specified, set it:
	if ( isset($ini['proxy']['port']) &&
		 !empty($ini['proxy']['port']) ) {
		$client->getIo()->setOptions(array(
			CURLOPT_PROXYPORT => intval($ini['proxy']['port'])
			));
	}
	
	// If there is a username specified, set it:
	if ( isset($ini['proxy']['username']) &&
		 !empty($ini['proxy']['username']) ) {
		$sProxyUserPwd = $ini['proxy']['username'];
		
		// If there is also a password specified, make sure it gets set too:
		if ( isset($ini['proxy']['password']) &&
			 !empty($ini['proxy']['password']) ) {
			$sProxyUserPwd .= ':';
			$sProxyUserPwd .= $ini['proxy']['password'];
		}
		
		$client->getIo()->setOptions(array(
			CURLOPT_PROXYUSERPWD => $sProxyUserPwd
			));
	}
}

$service  = new Google_Service_Calendar($client);

$currentTime = new Datetime();
$endTime = new DateTime("tomorrow");
$optParams = array(
	"orderBy" => "startTime",
	"singleEvents" => true,
	"timeMin" => $currentTime->format(DateTime::RFC3339),
	"timeMax" => $endTime->format(DateTime::RFC3339)
);
try
{
    $raw_events = $service->events->listEvents($ini['api']['calendar_id'],$optParams);
}
catch (Google_Exception $ex )
{
    $error_message = preg_replace('|https?://.+:|i',':',$ex->getMessage());
    print_r("<h1>Er ging iets fout in de communicatie met Google...</h1>");
    print_r("<p>" . $error_message . "</p>");
    die;
}
catch (Exception $ex)
{
    print_r("<h1>Er ging iets fout...</h1>");
    print_r("<p>" . $ex->getMessage() . "</p>");
    die;
}

$events = array();
while(true) {
  foreach ($raw_events->getItems() as $raw_event) {
  	$event = array();
	$event["start"] = new DateTime($raw_event->getStart()->dateTime);
	$event["end"] = new DateTime($raw_event->getEnd()->dateTime);
	$event["summary"] = $raw_event->getSummary();
	$event["location"] = $raw_event->getLocation();
	$events[] = $event;
  }
  $pageToken = $raw_events->getNextPageToken();
  if ($pageToken) {
    $optParams = array('pageToken' => $pageToken);
    $raw_events = $service->events->listEvents($ini['calendar_id'], $optParams);
  } else {
    break;
  }
}
?>
<html>
<head><title></title><link rel="stylesheet" type="text/css" href="calendar.css"></head>
<body>
<h1><?php
print_r("Bijeenkomsten ".$weekday[date('w')]." ".date('j')." ".$month[date('n')]." ".date('Y')); ?>
</h1>
<table>
<thead>
<tr><?php
if ( $ini['display_end_times'] ) {
	print_r('<td class="start_time_column"colspan="3" class="time_column_header">' . $time_of_day . '</td>');
}
else {
	print_r('<td class="start_time_column" class="time_column_header">' . $time_of_day . '</td>');
}
print_r('
		<td class="description_column" class="description_column_header">' . $description . '</td>
		<td class="location_column" class="location_column_header">' . $location . '</td>'); ?>
</tr>
</thead>
<tbody><?php
if ( $ini['display_after_start'] != '-1' )
{
    $display_after_start = new DateInterval( 'PT' . $ini['display_after_start'] );
}
$now = new DateTime("now");
foreach ( $events as $event ) {
        if ( $ini['display_after_start'] != '-1' ) {
            $eventTime = clone $event['start'];
            $eventTime->add($display_after_start);
            if( $eventTime->getTimestamp() < time() ){
                    continue;
            }
	}
	
	print_r('<tr><td class="start_time_column">' . $event["start"] -> format($ini['time_format']) . '</td>');
	if ( $ini['display_end_times'] ) {
		print_r('<td class="seperator_column">' . $time_seperator . '</td><td class="end_time_column">' . $event["end"] -> format($ini['time_format']) . '</td>');
	}
	print_r('<td class="description_column">' . $event["summary"] . '</td><td class="location_column">' . $event["location"] . '</td></tr>');}
?>
</body>
</table>
</body>
</html>
